http_client

Function http_client 

pub fn http_client<R: Runtime>(
    app: &AppHandle<R>,
    config: &HostConfig,
) -> Result<Arc<dyn HttpClient>>
One HTTP client for the whole application.

The user agent identifies the product and version, which several APIs require and most of them use when they need to contact an integrator about traffic.