builder

Function builder 

pub fn builder(config: &HostConfig) -> Builder<Wry>
A tauri::Builder with the Origin plugin set already registered.

Single-instance must be the first plugin, which is easy to get wrong by hand — one more reason for products not to assemble this themselves.